# Generated by roxygen2: do not edit by hand

export(fit_its_model)
export(generate_predictions)
export(its_plot)
export(slope_difference)
export(summary_its)
export(transform_data)
importFrom(AICcmodavg,predictSE.gls)
importFrom(dplyr,across)
importFrom(dplyr,arrange)
importFrom(dplyr,case_match)
importFrom(dplyr,case_when)
importFrom(dplyr,ensym)
importFrom(dplyr,filter)
importFrom(dplyr,group_by)
importFrom(dplyr,mutate)
importFrom(dplyr,pull)
importFrom(dplyr,recode)
importFrom(dplyr,row_number)
importFrom(dplyr,tibble)
importFrom(dplyr,ungroup)
importFrom(ggplot2,aes)
importFrom(ggplot2,geom_line)
importFrom(ggplot2,geom_point)
importFrom(ggplot2,geom_ribbon)
importFrom(ggplot2,ggplot)
importFrom(ggplot2,labs)
importFrom(ggplot2,scale_colour_manual)
importFrom(ggplot2,scale_fill_manual)
importFrom(ggplot2,theme)
importFrom(ggplot2,waiver)
importFrom(magrittr,"%>%")
importFrom(nlme,corARMA)
importFrom(nlme,gls)
importFrom(purrr,map)
importFrom(rlang,"!!!")
importFrom(rlang,"!!")
importFrom(rlang,":=")
importFrom(rlang,sym)
importFrom(scales,pvalue_format)
importFrom(stats,coef)
importFrom(stats,pt)
importFrom(stats,qt)
importFrom(stats,reformulate)
importFrom(stats,setNames)
importFrom(stats,terms)
importFrom(stats,vcov)
importFrom(stringr,str_sub)
importFrom(tibble,tribble)
